# Configure paths for libgnurdf
# Christian Hammond   5 August 2000

dnl AM_PATH_GNURDF([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for GNURDF, and define GNURDF_CFLAGS and GNURDF_LIBS
dnl
AC_DEFUN(AM_PATH_GNURDF,
[dnl 
dnl Get the cflags and libraries from the gnurdf-config script
dnl
AC_ARG_WITH(gnurdf-prefix,[  --with-gnurdf-prefix=PFX   Prefix where gnurdf is installed (optional)],
            gnurdf_config_prefix="$withval", gnurdf_config_prefix="")
AC_ARG_WITH(gnurdf-exec-prefix,[  --with-gnurdf-exec-prefix=PFX Exec prefix where gnurdf is installed (optional)],
            gnurdf_config_exec_prefix="$withval", gnurdf_config_exec_prefix="")
AC_ARG_ENABLE(gnurdftest, [  --disable-gnurdftest       Do not try to compile and run a test gnurdf program],
            , enable_gnurdftest=yes)


  if test x$gnurdf_config_exec_prefix != x ; then
     gnurdf_config_args="$gnurdf_config_args --exec-prefix=$gnurdf_config_exec_prefix"
     if test x${GNURDF_CONFIG+set} != xset ; then
        GNURDF_CONFIG=$gnurdf_config_exec_prefix/bin/gnurdf-config
     fi
  fi
  if test x$gnurdf_config_prefix != x ; then
     gnurdf_config_args="$gnurdf_config_args --prefix=$gnurdf_config_prefix"
     if test x${GNURDF_CONFIG+set} != xset ; then
        GNURDF_CONFIG=$gnurdf_config_prefix/bin/gnurdf-config
     fi
  fi

  AC_PATH_PROG(GNURDF_CONFIG, gnurdf-config, no)
	
  min_gnurdf_version=ifelse([$1], ,0.3.0,$1)
  AC_MSG_CHECKING([for gnurdf - version >= $min_gnurdf_version])
  no_gnurdf=""
  if test "$GNURDF_CONFIG" = "no" ; then
    no_gnurdf=yes
  else
    GNURDF_CFLAGS=`$GNURDF_CONFIG $gnurdf_config_args --cflags`
    GNURDF_LIBS=`$GNURDF_CONFIG $gnurdf_config_args --libs`
    gnurdf_config_major_version=`$GNURDF_CONFIG $gnurdf_config_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    gnurdf_config_minor_version=`$GNURDF_CONFIG $gnurdf_config_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    gnurdf_config_micro_version=`$GNURDF_CONFIG $gnurdf_config_args --version | \
           sed 's/[[^0-9]]*\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test "x$enable_gnurdftest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $GNURDF_CFLAGS"
      LIBS="$GNURDF_LIBS $LIBS"
dnl
dnl Now check if the installed gnurdf is sufficiently new. (Also sanity
dnl checks the results of gnurdf-config to some extent
dnl
      rm -f conf.gnurdftest
      AC_TRY_RUN([
#include <gnurdf.h>
#include <stdio.h>
#include <stdlib.h>

char *my_strdup(char *str)
{
	char *new_str;

	if (str)
	{
		new_str = (char *)malloc((strlen(str) + 1) * sizeof(char));
		strcpy(new_str, str);
	}
	else
		new_str = NULL;
	
	return new_str;
}

int 
main ()
{
  int major, minor, micro;
  char *tmp_version;

  system ("touch conf.gnurdftest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_gnurdf_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_gnurdf_version");
     exit(1);
   }

  if (($gnurdf_config_major_version  > major) ||
     (($gnurdf_config_major_version == major) && ($gnurdf_config_minor_version > minor)) ||
     (($gnurdf_config_major_version == major) && ($gnurdf_config_minor_version == minor) &&
      ($gnurdf_config_micro_version >= micro)))
    {
			return 0;
		}
		else
		{
      printf("\n*** 'gnurdf-config --version' returned %d.%d.%d, but gnurdf (%d.%d.%d)\n", 
             $gnurdf_config_major_version, $gnurdf_config_minor_version, $gnurdf_config_micro_version,
             major, minor, micro);
      printf ("*** was found! If gnurdf-config was correct, then it is best\n");
      printf ("*** to remove the old version of gnurdf. You may also be able to fix the error\n");
      printf("*** by modifying your LD_LIBRARY_PATH enviroment variable, or by editing\n");
      printf("*** /etc/ld.so.conf. Make sure you have run ldconfig if that is\n");
      printf("*** required on your system.\n");
      printf("*** If gnurdf-config was wrong, set the environment variable GNURDF_CONFIG\n");
      printf("*** to point to the correct copy of gnurdf-config, and remove the file config.cache\n");
      printf("*** before re-running configure\n");
			return 1;
    } 
}
],, no_gnurdf=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_gnurdf" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$GNURDF_CONFIG" = "no" ; then
       echo "*** The gnurdf-config script installed by gnurdf could not be found"
       echo "*** If gnurdf was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the GNURDF_CONFIG environment variable to the"
       echo "*** full path to gnurdf-config."
     else
       if test -f conf.gnurdftest ; then
        :
       else
          echo "*** Could not run gnurdf test program, checking why..."
          CFLAGS="$CFLAGS $GNURDF_CFLAGS"
          LIBS="$LIBS $GNURDF_LIBS"
          AC_TRY_LINK([
#include <gnurdf.h>
#include <stdio.h>
],      [ return ((gnurdf_major_version) || (gnurdf_minor_version) || (gnurdf_micro_version)); ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding gnurdf or finding the wrong"
          echo "*** version of gnurdf. If it is not finding gnurdf, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
          echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"
          echo "***"
          echo "*** If you have a RedHat 5.0 system, you should remove the gnurdf package that"
          echo "*** came with the system with the command"
          echo "***"
          echo "***    rpm --erase --nodeps gnurdf gnurdf-devel" ],
        [ echo "*** The test program failed to compile or link. See the file config.log for"
          echo "*** the exact error that occured. This usually means gnurdf was incorrectly"
          echo "*** installed or that you have moved gnurdf since it was installed. In the"
          echo "*** later case, you may want to edit the gnurdf-config"
	  echo "*** script: $GNURDF_CONFIG" ])
	  
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
     GNURDF_CFLAGS=""
     GNURDF_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(GNURDF_CFLAGS)
  AC_SUBST(GNURDF_LIBS)
  rm -f conf.gnurdftest
])
